<script setup>
import AdminAuthenticatedLayout from '@/Layouts/AdminAuthenticatedLayout.vue';
import { ref, onMounted, computed } from 'vue';
import InputError from '@/Components/InputError.vue';
import InputLabel from '@/Components/InputLabel.vue';
import PrimaryButton from '@/Components/PrimaryButton.vue';
import TextInput from '@/Components/TextInput.vue';
import Dropdown from '@/Components/Dropdown.vue';
import { Head, useForm } from '@inertiajs/vue3';

defineProps({
    status: {
        type: String,
    },
});

const flashMessage = ref('');
const form = useForm({
    type: '',
    name: '',
    email: '',
    password: '',
    password_confirmation: '',
    company: '',
    address1: '',
    address2: '',
    city: '',
    state: '',
    postal: '',
    country: '',
    phone: '',
    fax: '',
});

const dropdownOptions = ["Option 1", "Option 2", "Option 3"];
const selectedDropdownOption = "Option 1";

const submit = () => {
    form.post(route('admin.users.create'), {
        onSuccess: () => {
            form.reset()
            // Update your success message or perform other actions here
            flashMessage.value = "User added successfully!";
        },
        onError: (error) => {
            // Handle error case here, if needed
            console.error(error);
        }
    });
};
</script>

<template>

    <Head title="Add User" />

    <AdminAuthenticatedLayout>

        <template #header>
            <h2 class="font-semibold text-xl text-gray-800 leading-tight">Add User</h2>
        </template>

        <div class="py-12 container">
            <div v-if="flashMessage" class="max-w-7xl mx-auto sm:px-6 lg:px-8 font-bold text-green-600">
                <div class="form-row px-8">
                    <div class="col-md-6">
                        <h4>{{ flashMessage }}</h4>
                    </div>
                </div>
            </div>

            <div class="content-box sm:rounded-lg">
                <form @submit.prevent="submit">
                    <div class="form-row px-8">
                        <div class="mt-4 col-md-12">
                            <InputLabel for="type" value="User Type" />

                            <select id="type" class="w-full mt-1 block border-gray-300 rounded-md" required v-model="form.type">
                                <option value="">Select User Type</option>
                                <option value="admin">Admin</option>
                                <option value="user">User</option>
                            </select>

                            <InputError class="mt-2" :message="form.errors.type" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="name" value="Name" />

                            <TextInput
                                id="name"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.name"
                                required
                                autofocus
                                autocomplete="name"
                            />

                            <InputError class="mt-2" :message="form.errors.name" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="email" value="Email" />

                            <TextInput
                                id="email"
                                type="email"
                                class="mt-1 block w-full"
                                v-model="form.email"
                                required
                                autocomplete="username"
                            />

                            <InputError class="mt-2" :message="form.errors.email" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="password" value="Password" />

                            <TextInput
                                id="password"
                                type="password"
                                class="mt-1 block w-full"
                                v-model="form.password"
                                required
                                autocomplete="new-password"
                            />

                            <InputError class="mt-2" :message="form.errors.password" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="password_confirmation" value="Confirm Password" />

                            <TextInput
                                id="password_confirmation"
                                type="password"
                                class="mt-1 block w-full"
                                v-model="form.password_confirmation"
                                required
                                autocomplete="new-password"
                            />

                            <InputError class="mt-2" :message="form.errors.password_confirmation" />
                        </div>

                        <div class="mt-4 col-md-12">
                            <InputLabel for="company" value="Company" />

                            <TextInput
                                id="company"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.company"
                                required
                                autofocus
                                autocomplete="company"
                            />

                            <InputError class="mt-2" :message="form.errors.company" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="address1" value="Address1 (Primary)" />

                            <TextInput
                                id="address1"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.address1"
                                required
                                autofocus
                                autocomplete="address1"
                            />

                            <InputError class="mt-2" :message="form.errors.address1" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="address2" value="Address2" />

                            <TextInput
                                id="address2"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.address2"
                                autofocus
                                autocomplete="address2"
                            />

                            <InputError class="mt-2" :message="form.errors.address2" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="city" value="City" />

                            <TextInput
                                id="city"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.city"
                                required
                                autofocus
                                autocomplete="city"
                            />

                            <InputError class="mt-2" :message="form.errors.city" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="state" value="State" />

                            <TextInput
                                id="state"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.state"
                                required
                                autofocus
                                autocomplete="state"
                            />

                            <InputError class="mt-2" :message="form.errors.state" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="postal" value="Zip/Postal Code" />

                            <TextInput
                                id="postal"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.postal"
                                required
                                autofocus
                                autocomplete="postal"
                            />

                            <InputError class="mt-2" :message="form.errors.postal" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="country" value="Country" />

                            <TextInput
                                id="country"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.country"
                                required
                                autofocus
                                autocomplete="country"
                            />

                            <InputError class="mt-2" :message="form.errors.country" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="phone" value="Phone Number" />

                            <TextInput
                                id="phone"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.phone"
                                required
                                autofocus
                                autocomplete="phone"
                            />

                            <InputError class="mt-2" :message="form.errors.phone" />
                        </div>

                        <div class="mt-4 col-md-6">
                            <InputLabel for="fax" value="Fax" />

                            <TextInput
                                id="fax"
                                type="text"
                                class="mt-1 block w-full"
                                v-model="form.fax"
                                autofocus
                                autocomplete="fax"
                            />

                            <InputError class="mt-2" :message="form.errors.fax" />
                        </div>

                        <dropdown
                        :options="dropdownOptions"
                        :selected-option="selectedDropdownOption"
                        @select="handleDropdownSelect"
                        ></dropdown>

                    </div>

                    <div class="flex items-center justify-end mt-4">
                        <PrimaryButton class="ms-4" :class="{ 'opacity-25': form.processing }" :disabled="form.processing">
                            Add User
                        </PrimaryButton>
                    </div>
                </form>
            </div>
        </div>
    </AdminAuthenticatedLayout>
</template>
